"""
nosedjango cranks up the awesome for your Django project by giving you all the
testing goodness of the Nose ecosystem. Use multiprocess, xunit, coverage, etc
or even write your own plugin that hooks in to the NoseDjango plugin system (a
plugin with a plugin system!)
"""

VERSION = (1, 0, 6, '')

__version__ = ".".join(map(str, VERSION[:-1]))
__release__ = ".".join(map(str, VERSION))
__author__ = "Wes Winham"
__contact__ = "winhamwr@gmail.com"
__homepage__ = "http://github.com/nosedjango/nosedjango/"
__docformat__ = "restructuredtext"
